/**************************************************************

   Program Title:  TinyLCD Controller
   
   Program Name:  TinyLCD_Utilities.c	  Version: 0.86
   
   Author:  SS/WR	  					  Date:  February 29, 2008
   
   Compiled with ImageCraft ICCAVR Standard V7.02
   
   This file contains routines that implement a set of basic utility 
   functions for the TinyLCD controller.
   
   Copyright 2004-2008, SOC Robotics, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2004-2008, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC MACHINES, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SOC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: TinyLCD_Utilities.c,v $
 * Revision 0.86  2006/02/07  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom168v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
//#include <stdio.h>
#include "TinyLCD_Uart.h"
#include "TinyLCD_Defines.h"
#include "TinyLCD_Extern.h"

//*********************************************************
//*********************************************************
//      Utilities
//*********************************************************
//*********************************************************
void Delay(void)
{
	unsigned char a, b;

	for (a = 1; a; a++)
		for (b = 1; b; b++)
			;
}

void ShortDelay(int cnt)
{
 	unsigned char inbyte;
	int i;
	
    for(i=0; i<cnt; i++)  {
	    inbyte = 0x55;
		}
}

void LongDelay(int cnt)
{
 	 while(cnt > 0) {
	 	 Delay();
		 cnt--;
		 }
}

void Delaymsec(int delayvalue)
{
 	 mseccountdown2 = delayvalue;
	 while(mseccountdown2) ;
}

// Function to initiate an EEPROM write
// writes the specified data byte to the specified location
// this will fail if the EEPROM is not ready!
void RTEEPROMwrite(int location, unsigned char databyte)
{
	unsigned char savedSREG;
	EEAR = location;								// set address
	EEDR = databyte;								// set data	
	savedSREG = SREG;								// keep setting so it can be restored
	CLI();											// disable interrupts
	EECR |= BIT(EEMWE);							// set "write enable" bit
	EECR |= BIT(EEWE);							// set "write" bit
	SREG = savedSREG;								// restore SREG
	EEAR = 0;
}

// EEPROM writes take about 8ms - so poll until done
// Do not use ICC V7 function EEPROMwrite() - this routine turns interrupts off!
void EEPROMWrite(int location, unsigned char databyte)
{
 	 while(!RTEEPROMReady())  ;
 	 RTEEPROMwrite(location,databyte);
 	 while(!RTEEPROMReady())  ;
}

unsigned char hextobyte(unsigned char inbyte)
{
	 if((inbyte >= 'A')&(inbyte<='F')) return (inbyte - 'A' + 10);
	 if((inbyte >= 'a')&(inbyte<='f')) return (inbyte - 'a' + 10);
	 else return (inbyte - '0');
}

//  Convert byte to ASCII hex
void bytetohex(unsigned char byte)
{
    unsigned char inbyte,inchar;
	
	inbyte = byte & 0x0f;
	if(inbyte > 9) hexbyte[1] = (inbyte - 9) + 0x40;
	else hexbyte[1] = 0x30 + inbyte;
	inbyte = byte & 0xf0;
	inbyte >>= 4;
	if(inbyte >9) hexbyte[0] = (inbyte - 9) + 0x40;
	else hexbyte[0] = 0x30 + inbyte;
    hexbyte[2] = 0x00;
}

// function to test if the EEPROM is ready for a read or write operation
// returns non zero if ready, zero if not ready 
unsigned char RTEEPROMReady(void)
{
	return !(EECR & 0x02);
}

void LED_Power(unsigned char state)
{
 	 if(state==ON)  ClrBit(PORTD,PIND5);
	 else  SetBit(PORTD,PIND5);
}

void LCD_LED_Power(unsigned char state)
{
 	 if(state==ON)  SetBit(PORTD,PIND6);
	 else  ClrBit(PORTD,PIND6);
}

// Key 1 is far left Key 4 is far right
// Key pressed is active low
unsigned char CheckKeyState(unsigned char key)
{
 	unsigned char inkey;
	
 	if(key==KEY1) inkey = PIND&0x04;
	else if(key==KEY2) inkey = PIND&0x08;
	else if(key==KEY3) inkey = PIND&0x10;
	else if(key==KEY4) inkey = PIND&0x80;
	else return 1;
	if(inkey>0) return 0;
	else return 1;
}

void ToggleKeyState(char key)
{
 	 if(key==1) {
	     if(key1toggle==1) key1toggle = 0;
		 else key1toggle = 1;
		 }
 	 if(key==2) {
	     if(key2toggle==1) key2toggle = 0;
		 else key2toggle = 1;
		 }
 	 if(key==3) {
	     if(key3toggle==1) key3toggle = 0;
		 else key3toggle = 1;
		 }
 	 if(key==4) {
	     if(key4toggle==1) key4toggle = 0;
		 else key4toggle = 1;
		 }
}

int Read_ADC(unsigned char channel, unsigned char ref)
{
 	unsigned char low,high;
	
	if (ref == ADCINTERNAL)
	{
	 ADMUX = 0xC0;//internal reference
	} else if (ref == ADCEXTERNAL)
	{
	  ADMUX = 0x40;//AVCC is our reference
	} else return 0;
	//As the voltage reference has been changed we ignore the first value read
	ADCSRA = (1<<ADEN)|(1<<ADSC);
	while(!(ADCSRA&(1<<ADIF))) ;  // wait for adc to complete
	Delay();
	
	
	
	
 	if(channel==0)  {
	    //Already set to channel 0  //  ADC0
		ADCSRA = (1<<ADEN)|(1<<ADSC);
		}
	else if(channel==1) {
	    ADMUX |= 0x01;   //  ADC1
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }	
	else if(channel==6) {
	    ADMUX |= 0x06;   //  ADC6
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else if(channel==7) {
	    ADMUX |= 0x07;   //  ADC7
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else return 0;
	
	while(!(ADCSRA&(1<<ADIF))) ;  // wait for adc to complete
	Delay();
	low = ADCL;
	high = ADCH;
	return (low+high*256);
}

