/**************************************************************

   Program Title: SmartLCD Controller 
   
   Program Name: SmartLCD_LCD.c		  Version: 0.01
   
   Author:  SS/WR	  		  Date:  Febuary 27, 2008
   
   Compiled with ImageCraft ICCAVR Standard V7.1
   
   Copyright 2004-2008, SOC Machines, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright (C) 2008 by SOC Machines, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC MACHINES, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SOC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-machines.com
 */



#include <iom168v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
//#include <stdio.h>
#include "TinyLCD_Uart.h"
#include "TinyLCD_Defines.h"
#include "TinyLCD_Extern.h"
//#include "USI_TWI_Slave.h"

#include "SmartLCD_LCD.h"
#include "SmartLCD_Accelerometer.h"


const unsigned char line1chars[] = {'S','m','a','r','t','L','C','D',' ',' ',' ',' ',0x00};
const unsigned char line2chars[] = {'V','e','r','s','i','o','n',' ','1','.','0','1',0x00};
const unsigned char line3chars[] = {'S','O','C',' ','R','o','b','o','t','i','c','s',0x00};
const unsigned char line4chars[] = {'w','a','i','t','i','n','g',' ',' ',' ',' ',' ',0x00};
unsigned char line1[13],line2[13],line3[13],line4[13];
unsigned char cursorposition,cursormax,rowptr,colptr,lineptr,escmode;
unsigned char lcdphoneantennasymbols,lcdstate,symbolmode,voltagevolume;
unsigned char lcdchiptype;
//frameerror,dataoverrun,numstrg[9],

unsigned int count;
//seconds,minutes,hours,days,

char  flip2;
//rxcnt,checkflag,rxcntmax,

void   LCDWriteSerialByte(unsigned char inchar)
{
 	unsigned char i,mask;

	mask = 0x80;
	for(i=0; i<8; i++) {
	    ClrBit(LCDDATA,LCD_SCLK);
		if((inchar&mask)) SetBit(LCDDATA,LCD_SI);
		else ClrBit(LCDDATA,LCD_SI);
		mask >>= 1;
		SetBit(LCDDATA,LCD_SCLK);
	    }
}

void   LCDprintchar(unsigned char inchar)
{
	LCDCONTROL |= BIT(LA0); // raise A0 high
	LCDCONTROL &= ~BIT(CS); // set CS low
	ShortDelay(1);
	LCDWriteSerialByte(inchar);
	LCDCONTROL |= BIT(CS); // release CS
	ShortDelay(2);	
}

void   LCDwritecommand(unsigned char inchar)
{ 		
	LCDCONTROL &= ~BIT(LA0); /* set A0 low */
	LCDCONTROL &= ~BIT(CS);  /* set RS low */
	ShortDelay(1);
	LCDWriteSerialByte(inchar);
	LCDCONTROL |= BIT(CS); // release CS
	ShortDelay(2);
}



void   LCDDisplayChar(unsigned char address, unsigned char inchar)
{
 	LCDwritecommand(LCDRAMADDRESS|address);
	LCDprintchar(inchar);
}

void LCD_Write(unsigned char address,unsigned char data)
{
	LCDwritecommand(LCDRAMADDRESS|address);
	LCDprintchar(data);
}

void   LCDdisplays(unsigned char address, char *instrg)
{
	char i,j;

	i = 0;
	LCDwritecommand(LCDRAMADDRESS|address);
	while(instrg[i]!=0x00) LCDprintchar(instrg[i++]);

}

void   LCDprints(char *instrg)
{
	char i,j;

	i = 0;
	while(instrg[i]!=0x00) {
		if(cursorposition>=cursormax) {
		   cursorposition = 0;
		   return ; // or wrap line
		   }
		else  {
			  if(instrg[i]==LF) LCDwritecommand(LCDCLR);
			  else if(instrg[i]==CR) LCDwritecommand(LCDHOME);
			  else if(instrg[i]==TAB) for(j=0; j<6; j++) LCDprintchar(0x20);
			  else LCDprintchar(instrg[i++]);
			  cursorposition++;
			  }
		}
}

void LCD_Symbols(unsigned char state)
{ 	 
	 int i;
	 
	 if(state==ON) {
	 	 LCDwritecommand(LCDRAMADDRESS|0x70);
	 	 for(i=0; i<12; i++)  LCDprintchar(0x0b);
		 }
	 else if(state==OFF) {
	 	 LCDwritecommand(LCDRAMADDRESS|0x70);
	 	 for(i=0; i<12; i++)  LCDprintchar(0x00);
		 }
}

void SetBuffers(unsigned char inchar)
{
 	 unsigned char i;
	 
	 for(i=0; i<12; i++) {
	     line1[i] = inchar;
		 line2[i] = inchar;
		 line3[i] = inchar;
		 line4[i] = inchar;
		 }
}

void Clear_LCD()
{
 	 int i;
	 
	 // Clear 4x12 display
	 for(i=0; i<12; i++) LCD_Write(LCDRAMADDRESS|0x30+i,' ');
	 for(i=0; i<12; i++) LCD_Write(LCDRAMADDRESS|0x40+i,' ');
	 for(i=0; i<12; i++) LCD_Write(LCDRAMADDRESS|0x50+i,' ');
	 for(i=0; i<12; i++) LCD_Write(LCDRAMADDRESS|0x60+i,' ');
	 
	 // Clear buffers
	 SetBuffers(' ');
	 
	 // Clear all symbols
	 LCD_Symbols(OFF);
}


/******************************************
  LCD interface control logic:
       CS -  0 select device
       R/W - 0 WR, 1 RD,
       LA0 - 0 command, 1 data
 ******************************************/
void Init_LCD()
{
     lcdchiptype = LCDCHIPE1007;  // if lcd display is E1007
	 
	 SetBit(PORTB,PINB6);  // set clock high
	 // Reset LCD - hold in reset for 10usec
	 LCDCONTROL &= ~BIT(LCDRESET);  // Set Reset line low
	 ShortDelay(200);
	 LCDCONTROL |= BIT(LCDRESET);  // Set Reset line high
	 ShortDelay(50);
	
	// Static Icon off - display on - RF circuit on - clear RAM
	// Set display volume

// System set command
//   D3-N2, D2-N1, D0-CG
//   N2/1 -> 0,0  2 lines
//   N2/1 -> 0,1  3 lines
//   N2/1 -> 1,0  4 lines
//   CG   -> 1 CGRAM used, 0 not used
     LCDwritecommand(LCDSYSTEMSET|LCD4LINE|LCDCGON);

// Static Display Command
//   D1/0 - 0,0  Display OFF
//   D1/0 - 0,1  1-2Hz blink
//   D1/0 - 1,0  3-4Hz blink
//   D1/0 - 1,1  Display ON
	 LCDwritecommand(LCDSTATICDISPLAY|LCDDISPLAYON);
	 
// Display control command
//   D3-C, D2-B, D1-DC, D0-D
//   C  -> 1 cursor on, 0 off
//   DC -> 1 double cursor on, 0 off
//   B  -> 1 blink on, 0 off
//   D  -> 1 display on, 0 off	 
//	 LCDwritecommand(LCDDISPLAY|LCDCURSORON|LCDCURSORBLINK|LCDCURSORDISPLAYON);
	 LCDwritecommand(LCDDISPLAY|LCDCURSORDISPLAYON);

// Power Save Command
//   D1-PS, D0-O
//   PS -> 1 power save on, 0 off
//   O  -> 1 oscillator circuit on, 0 off
     LCDwritecommand(LCDPOWERSAVE|LCDPOWERSAVEOFF|LCDOSCON);

	 // Set data pointer to DDRAM
	 LCDwritecommand(LCDRAMADDRESS|0x30);

	 // Wait 20ms for power supply to stabilize
	 ShortDelay(30000);	 

	 // Power supply control
	 //   D2-VC, D1-VF, D0-P
	 //   VC -> 1 voltage regulator on, 0 off
	 //   VF -> 1 voltage follower on, 0 off
	 //   P  -> 1 voltage booster on, 0 off
	 LCDwritecommand(LCDPOWERSUPPLY|LCDVOLTREGON|LCDVOLTFOLLOWON|LCDVOLTBOOSTON);
//	 LCDwritecommand(LCDPOWERSUPPLY|LCDVOLTREGON|LCDVOLTFOLLOWON);

	 // Electronic volume setting
	 //   D3-0 - set display brightness
	 // TBD - real VDD and adjust Voltage Volume accordingly
	 voltagevolume = 0x09;
     LCDwritecommand(LCDVOLREG|voltagevolume); 

	 // move cursor to home position command
	 LCDwritecommand(LCDHOME); 
 
 	 lcdphoneantennasymbols = 0;
	 cursormax = 12;
	 cursorposition = 0;
	 rowptr = 1;
	 colptr = 0;
	 lineptr = LINE1;
	 lcdstate = NO_ACTIVE_STATE;
	 symbolmode = NO_ACTIVE_STATE;
}

void DisplayLCDBuffers()
{
	 LCDdisplays(LINE1,line1);
   	 LCDdisplays(LINE2,line2);
   	 LCDdisplays(LINE3,line3);
   	 LCDdisplays(LINE4,line4);	 
}

void LoadSignon()
{
 	 unsigned char i;
	 
	 cstrcpy(line1,line1chars);
	 cstrcpy(line2,line2chars);
	 cstrcpy(line3,line3chars);
	 cstrcpy(line4,line4chars);
}

void ShiftUpLine()
{
 	 unsigned char i;
	 
	 for(i=0; i<12; i++) {
	     line1[i] = line2[i];
		 line2[i] = line3[i];
		 line3[i] = line4[i];
		 line4[i] = ' ';
		 }
     DisplayLCDBuffers();
	 cursorposition = 0;
}

void PutCharinBuffer(unsigned char row,unsigned char address,unsigned char inchar)
{
    if(row==0)  line1[address] = inchar;
	else if(row==1)  line2[address] = inchar;
	else if(row==2)  line3[address] = inchar;
	else if(row==3)  line4[address] = inchar;
}

void LCD_Dsymbol(unsigned char state)
{
    if(state==ON) LCD_Write(0x70,0x08);
	else if(state==OFF) LCD_Write(0x70,0);
}

void LCD_Rsymbol(unsigned char state)
{
    if(state==ON) LCD_Write(0x75,0x02);
	else if(state==OFF) LCD_Write(0x75,0);
}

void LCD_Vsymbol(unsigned char state)
{
    if(state==ON) LCD_Write(0x78,0x08);
	else if(state==OFF) LCD_Write(0x78,0);
}

void LCD_Phone(unsigned char state)
{
    if(state==LCD_PHONE_ON) {
	    lcdphoneantennasymbols |= LCD_PHONE_SYMBOL;
		LCD_Write(0x73,lcdphoneantennasymbols);
		LCD_Write(0x74,0);
	    }
	else if(state==LCD_SLASHPHONE) {
	    lcdphoneantennasymbols |= LCD_PHONE_SYMBOL;
		LCD_Write(0x73,lcdphoneantennasymbols);
		LCD_Write(0x74,0x08);
	    }
	else if(state==LCD_PHONE_OFF) {
	    lcdphoneantennasymbols &= ~LCD_PHONE_SYMBOL;
		LCD_Write(0x73,lcdphoneantennasymbols);
		LCD_Write(0x74,0);
	    }
}

void LCD_Envelope(unsigned char state)
{
    if(state==ON) LCD_Write(0x76,0x02);
	else if(state==OFF) LCD_Write(0x76,0);
}


void LCD_Battery(unsigned char level)
{
 	 if(level==LCD_BATTERY_EMPTY)  {
	     LCD_Write(0x79,0x02);
	     LCD_Write(0x7a,0);
	     LCD_Write(0x7b,0);
		 }
 	 if(level==LCD_BATTERY_QUARTER)  {
	     LCD_Write(0x79,0x02);
	     LCD_Write(0x7a,0);
	     LCD_Write(0x7b,0x08);
		 }
 	 if(level==LCD_BATTERY_HALF)  {
	     LCD_Write(0x79,0x02);
	     LCD_Write(0x7a,0x02);
	     LCD_Write(0x7b,0x08);
		 }
 	 if(level==LCD_BATTERY_THREEQUARTER)  {
	     LCD_Write(0x79,0x02);
	     LCD_Write(0x7a,0x02);
	     LCD_Write(0x7b,0x0b);
		 }
 	 if(level==LCD_BATTERY_FULL)  {
	     LCD_Write(0x79,0x02);
	     LCD_Write(0x7a,0x0b);
	     LCD_Write(0x7b,0x0b);
		 }
 	 if(level==LCD_BATTERY_OFF)  {
	     LCD_Write(0x79,0);
	     LCD_Write(0x7a,0);
	     LCD_Write(0x7b,0);
		 }
}

void LCD_Antenna(unsigned char level)
{
 	 if(level==LCD_ANTENNA_EMPTY)  {
	     lcdphoneantennasymbols &= ~LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0x08);
	     LCD_Write(0x72,0);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
  	 if(level==LCD_ANTENNA_QUARTER)  {
	     lcdphoneantennasymbols &= ~LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0x0b);
	     LCD_Write(0x72,0);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
 	 if(level==LCD_ANTENNA_HALF)  {
	     lcdphoneantennasymbols &= ~LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0x0b);
	     LCD_Write(0x72,0x08);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
 	 if(level==LCD_ANTENNA_THREEQUARTER)  {
	     lcdphoneantennasymbols &= ~LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0x0b);
	     LCD_Write(0x72,0x0b);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
 	 if(level==LCD_ANTENNA_FULL)  {
	     lcdphoneantennasymbols |= LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0x0b);
	     LCD_Write(0x72,0x0b);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
 	 if(level==LCD_ANTENNA_OFF)  {
	     lcdphoneantennasymbols &= ~LCD_BIGANTENNA_SYMBOL;
	     LCD_Write(0x71,0);
	     LCD_Write(0x72,0);
	     LCD_Write(0x73,lcdphoneantennasymbols);
		 }
}

unsigned char GetRowfromLine(unsigned char line)
{
 	 if(line==LINE1) return 0;
	 if(line==LINE2) return 1;
	 if(line==LINE3) return 2;
	 if(line==LINE4) return 3;
	 return 0;
}

void SendCharToDisplay(unsigned char inchar)
{
	if(cursorposition>11) {
		if(lineptr==LINE4) ShiftUpLine();
		else {
			lineptr += 0x10;
			cursorposition = 0;
			}
		}				
	LCDDisplayChar(lineptr+cursorposition,inchar);
	PutCharinBuffer(GetRowfromLine(lineptr),inchar,cursorposition);
	cursorposition++;
}

void IncrementLinePtr()
{
    if(lineptr==LINE1)  lineptr = LINE2;
	else if(lineptr==LINE2) lineptr = LINE3;
	else if(lineptr==LINE3) lineptr = LINE4;
}


void ParseEscSubCommand(unsigned char inchar)
{
 	 switch (symbolmode) {
		case TWI_ADDRESS_STATE:
		    if(inchar==LCD_PHONE_ON) LCD_Phone(LCD_PHONE_ON);
			else if(inchar==LCD_SLASHPHONE) LCD_Phone(LCD_SLASHPHONE);
			else if(inchar==LCD_PHONE_ON) LCD_Phone(LCD_PHONE_OFF);
			break;
		case LED_BLINK_STATE:
		    if(inchar==LCD_PHONE_ON) LCD_Phone(LCD_PHONE_ON);
			else if(inchar==LCD_SLASHPHONE) LCD_Phone(LCD_SLASHPHONE);
			else if(inchar==LCD_PHONE_ON) LCD_Phone(LCD_PHONE_OFF);
			break;
		case VOLTAGE_STATE:
		    if(inchar=='o') LCD_Vsymbol(ON);
			else if(inchar=='f') LCD_Vsymbol(OFF);
			break;
		}
 	 lcdstate = NO_ACTIVE_STATE;
}

void ParseSymbolCommand(unsigned char inchar)
{
 	 switch (symbolmode) {
		case ANTENNA_STATE:
		    LCD_Antenna(inchar);
			break;
		case BATTERY_STATE:
		    LCD_Battery(inchar);
			break;
		case VSYM_STATE:
		    if(inchar=='o') LCD_Vsymbol(ON);
			else if(inchar=='f') LCD_Vsymbol(OFF);
			break;
		case DSYM_STATE:
		    if(inchar=='o') LCD_Dsymbol(ON);
			else if(inchar=='f') LCD_Dsymbol(OFF);
			break;
		case RSYM_STATE:
		    if(inchar=='o') LCD_Rsymbol(ON);
			else if(inchar=='f') LCD_Rsymbol(OFF);
			break;
		case ENVELOPE_STATE:
		    if(inchar=='o') LCD_Envelope(ON);
			else if(inchar=='f') LCD_Envelope(OFF);
			break;
		case PHONE_STATE:
		    LCD_Phone(inchar);
			break;
	     }
 	 lcdstate = NO_ACTIVE_STATE;
	 symbolmode = NO_ACTIVE_STATE;
}

void ParseEscCommand(unsigned char inchar)
{
    switch (inchar) {
	    case 'c':
		    Clear_LCD();
			lineptr = LINE1;
			cursorposition = 0;
			escmode = OFF;
			break;
		case '1':
		    lineptr = LINE1;
		    cursorposition = 0;
			escmode = OFF;
			break;
		case '2':
		    lineptr = LINE2;
			cursorposition = 0;
			escmode = OFF;
			break;
		case '3':
		    lineptr = LINE3;
			cursorposition = 0;
			escmode = OFF;
			break;
		case '4':
		    lineptr = LINE4;
			cursorposition = 0;
			escmode = OFF;
			break;
		case 'o':
		    LCD_LED_Power(ON);
			escmode = OFF;
			break;
		case 'f':
		    LCD_LED_Power(OFF);
			escmode = OFF;
			break;
		case 's':
		    lcdstate = LCD_SYMBOL_STATE;
			break;
		case 'v':
		    lcdstate = VOLTAGE_STATE;
			break;
		case 'l':
		    lcdstate = LED_BLINK_STATE;
			break;
		case 't':
		    lcdstate = TWI_ADDRESS_STATE;
			break;
		default:
		    escmode = OFF;
			break;
		}
	escmode = OFF;
}

void ParseChar(unsigned char inchar)
{
	if(escmode==ON) {
		ParseEscCommand(inchar);
		}
	else {
	    if(symbolmode) ParseSymbolCommand(inchar);
	    else if(lcdstate==LCD_SYMBOL_STATE) symbolmode = inchar;
		else if(lcdstate) ParseEscSubCommand(inchar);
		else {
	      switch (inchar) {
		    case ESC:
				escmode = ON;  
				break;
		    case CR:
				cursorposition = 0; 
				break;
		    case LF:
				if(lineptr==LINE4) ShiftUpLine();
 				else IncrementLinePtr();
				break;
		    case 0x01:
				LCD_Vsymbol(ON); 
				break;
		    case 0x02:
				LCD_Vsymbol(OFF);  
				break;
		    case 0x03:
				LCD_Dsymbol(ON); 
				break;
		    case 0x04:
				LCD_Dsymbol(OFF);  
				break;
		    case 0x05:
				LCD_Rsymbol(ON); 
				break;
		    case 0x06:
				LCD_Rsymbol(OFF);  
				break;
		    case 0x07:
				LCD_Envelope(ON); 
				break;
		    case 0x08:
				LCD_Envelope(OFF);  
				break;
			default:
			    SendCharToDisplay(inchar);
				break;
			}
		  }
		}
}



void ParseStrg(unsigned char *instrg)
{
 	 unsigned char i;
	 
	 for(i=0; i<strlen(instrg); i++)  ParseChar(instrg[i]);
}

void PutStringinBuffer(unsigned char row,unsigned char column,char *strg)
{	 
	 unsigned char i;
	 
	 for(i=0; i<strlen(strg); i++)  PutCharinBuffer(row,column+i,strg[i]);
	 while (i<12)
	 {
	  PutCharinBuffer(row,column+i,' ');
	  i++;
	 }
}

unsigned char GetLine(unsigned char row)
{
    if(row==0) return LINE1;
	if(row==1) return LINE2;
	if(row==2) return LINE3;
	if(row==3) return LINE4;
	return LINE1;
}

void Display_Voltage_Volume(unsigned char row,unsigned char column)
{
 	 char strg[5];
 	 int analogvalue;
	 
	 PutStringinBuffer(row,column,"Volt v=");
	 bytetohex(voltagevolume);
	 strcpy(strg,hexbyte);
	 PutStringinBuffer(row,column+7,hexbyte);
}

void Display_Voltage_Reference(unsigned char row,unsigned char column)
{
 	 char strg[5];
 	 int analogvalue,newvoltvol;
	 
	 PutStringinBuffer(row,column,"Analog0=");
 	 analogvalue = Read_ADC(0, ADCINTERNAL);
	  
	 bytetohex((analogvalue>>8)&0xff);
	 strcpy(strg,hexbyte);
	 bytetohex((analogvalue&0x00ff));
	 strcat(strg,hexbyte);
	 PutStringinBuffer(row,column+8,strg);
}

void  Adjust_VoltageVolume()
{
	 if((voltagevolume=(1+(574-Read_ADC(0, ADCINTERNAL))/14))>0x0f) 
//	 if((voltagevolume=(1+(554-Read_ADC(0, ADCINTERNAL))/14))>0x0f) 
	     voltagevolume = 0x0c;
	 LCDwritecommand(LCDVOLREG|voltagevolume); 
}
void Display_Display_Parameters()
{
	if(flip2==ON) {
		//LCD_Symbols(ON);
		Display_Voltage_Reference(0,0);
		Display_Voltage_Volume(1,0);
		DisplayTime(3,0);
		LED_Power(OFF);
		//LCD_LED_Power(ON);
		flip2 = YES;
		//line4[11] = '.';
    	DisplayLCDBuffers();
		}
	else {
		//line4[11] = ' ';
		//LCD_Symbols(OFF);	
    	DisplayLCDBuffers();
		//LCD_LED_Power(OFF);
		LED_Power(ON);
		flip2 = NO;
		}
	mseccountdown2 = 250;
}

void DisplayPointPattern()
{
	Delaymsec(750);
	line4[7] = '.';
	DisplayLCDBuffers();
	Delaymsec(750);
	line4[8] = '.';
	DisplayLCDBuffers();
	Delaymsec(750);
	line4[9] = '.';
	DisplayLCDBuffers();
	Delaymsec(750);
	line4[10] = '.';
	DisplayLCDBuffers();
	Delaymsec(750);
	line4[11] = '.';
	DisplayLCDBuffers();
	Delaymsec(750);
}

void Display_Count()
{
 	char outstrg[12];
	
	rtccountdown1 = 256;
	bytetohex((count>>8)&0xff);
	strcpy(outstrg,hexbyte);
	bytetohex((count&0x00ff));
	strcat(outstrg,hexbyte);
	PutStringinBuffer(2,0,"count=");
	PutStringinBuffer(2,6,outstrg);
	count++;
}

void SplashScreen()
{
	LoadSignon();
	LCD_Symbols(ON);
	DisplayLCDBuffers();
	DisplayPointPattern();
	Clear_LCD();
	Delaymsec(250);
}


void bytetoint(unsigned char byte)
{
 	 unsigned char tens,ones;
	 
	 tens = byte/10;
	 ones = byte%10;
	 hexbyte[0] = tens + '0';
	 hexbyte[1] = ones + '0';
	 hexbyte[2] = 0x00;
}



void DisplayTime(unsigned char row,unsigned char column)
{
 	 char strg[9];
	 	
	 //PutStringinBuffer(column,"t=");
	 bytetoint(hours);
	 strcpy(strg,hexbyte);
	 strcat(strg,":");
	 bytetoint(minutes);
	 strcat(strg,hexbyte);
	 strcat(strg,":");
	 bytetoint(seconds);
	 strcat(strg,hexbyte);
	 PutStringinBuffer(row,column,strg);
}