/**************************************************************

   Program Title:  SmartLCD Controller
   
   Program Name:  SmartLCD_Utilities.c	  Version: 0.85
   
   Author:  SS	  					  Date:  August 10, 2008
   
   Compiled with ImageCraft ICCAVR Standard V7.13A
   
   This file contains routines that implement a set of basic utility 
   functions for the SmartLCD controller.
   
   Copyright 2004-2008, SOC Robotics, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2004-2006, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC ROBOTICS, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL OC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */

/*
 * $Log: SmartLCD_Utilities.c,v $
 * Revision 0.86  2006/02/07  SS
 *    2-wire interface, 8MHz clock, AVR Flash writer, XON/XOFF, 38,700baud
 * Revision 0.52  2005/06/04 18:36:42  SS
 * Preview release
 *
 */
#include <iom168v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
//#include <stdio.h>
#include "SmartLCD_Uart.h"
#include "SmartLCD_Defines.h"
#include "SmartLCD_Extern.h"

//*********************************************************
//*********************************************************
//      Utilities
//*********************************************************
//*********************************************************
void Delay(void)
{
	unsigned char a, b;

	for (a = 1; a; a++)
		for (b = 1; b; b++)
			;
}

void ShortDelay(int cnt)
{
 	unsigned char inbyte;
	int i;
	
    for(i=0; i<cnt; i++)  {
	    inbyte = 0x55;
		}
}

void LongDelay(int cnt)
{
 	 while(cnt > 0) {
	 	 Delay();
		 cnt--;
		 }
}

void Delaymsec(int delayvalue)
{
 	 mseccountdown2 = delayvalue;
	 while(mseccountdown2) ;
}

void printint(int intvalue)
{
 	 char outvalue[6];
	 
 	 int  tenthousands, thousands, hundreds, tens;
	 
	 if(intvalue >= 0) putchar(' ');
	 else {
	 	  putchar('-');
	 	  intvalue *= -1;
		  }
	 tenthousands = intvalue/10000;
	 intvalue -= (tenthousands*10000);
	 thousands = intvalue/1000;
	 intvalue -= (thousands*1000);
	 hundreds = intvalue/100;
	 intvalue -= (hundreds*100);
	 tens = intvalue/10;
	 	  outvalue[0] = '0' + hundreds;
	 	  outvalue[1] = '0' + tens;
	 	  outvalue[2] = '.';
	 	  outvalue[3] = '0' + intvalue%10;
	 	  outvalue[4] = 0x00;
	 outvalue[5] = 0x00;
}

unsigned char hextobyte(unsigned char inbyte)
{
	 if((inbyte >= 'A')&(inbyte<='F')) return (inbyte - 'A' + 10);
	 if((inbyte >= 'a')&(inbyte<='f')) return (inbyte - 'a' + 10);
	 else return (inbyte - '0');
}

//  Convert byte to ASCII hex
void bytetohex(unsigned char byte)
{
    unsigned char inbyte,inchar;
	
	inbyte = byte & 0x0f;
	if(inbyte > 9) hexbyte[1] = (inbyte - 9) + 0x40;
	else hexbyte[1] = 0x30 + inbyte;
	inbyte = byte & 0xf0;
	inbyte >>= 4;
	if(inbyte >9) hexbyte[0] = (inbyte - 9) + 0x40;
	else hexbyte[0] = 0x30 + inbyte;
    hexbyte[2] = 0x00;
}

void  EEPROM_write(int uiAddress,unsigned char ucData)
{
    //  Wait for completion of previous write
	while(EECR&(1<<EEPE));
	
	// Set up address and Data registers
	EEAR = uiAddress;
	EEDR = ucData;
	
	// Write logical one to EEMPE
	EECR |= (1<<EEMPE);
	
	// Start eeprom write by setting EEPE
	EECR |= (1<<EEPE);
}

unsigned char EEPROM_read(int uiAddress)
{
    // Wait for completion of previous write
	while(EECR&(1<<EEPE));
	
	// Setup address
	EEAR = uiAddress;
	
	// Start eeprom read by writing EERE
	EECR |= (1<<EERE);
	
	// Return data from data register
	return EEDR;
}

void LED_Power(unsigned char state)
{
 	 if(state==ON)  ClrBit(PORTD,PIND5);
	 else  SetBit(PORTD,PIND5);
}

void LCD_LED_Power(unsigned char state)
{
 	 if(state==ON)  SetBit(PORTD,PIND6);
	 else  ClrBit(PORTD,PIND6);
}

// Key 1 is far left Key 4 is far right
// Key pressed is active low
unsigned char CheckKeyState(unsigned char key)
{
 	unsigned char inkey;
	
 	if(key==KEY1) inkey = PIND&0x04;
	else if(key==KEY2) inkey = PIND&0x08;
	else if(key==KEY3) inkey = PIND&0x10;
	else if(key==KEY4) inkey = PIND&0x80;
	else return 1;
	if(inkey>0) return 0;
	else return 1;
}

int Read_ADC(unsigned char channel)
{
 	unsigned char low,high;
	
 	if(channel==0)  {
	    ADMUX = (1<<REFS1)|(1<<REFS0);  // use internal vref, ADC0
		ADCSRA = (1<<ADEN)|(1<<ADSC);
		}
	else if(channel==1) {
	    ADMUX = 0x01|(1<<REFS0);   //  ADC6  use external AVCC
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else if(channel==2) {
	    ADMUX = 0x02|(1<<REFS0);   //  ADC7
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else if(channel==6) {
	    ADMUX = 0x06|(1<<REFS0);   //  ADC6
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else if(channel==7) {
	    ADMUX = 0x07|(1<<REFS0);   //  ADC7
		ADCSRA = (1<<ADEN)|(1<<ADSC);
	    }
	else return 0;
	
	while(!(ADCSRA&(1<<ADIF))) ;  // wait for adc to complete
	low = ADCL;
	high = ADCH;
	return (low+high*256);
}

int sensitivity;

void setAccelerometerRange(unsigned char range)
{
	if (range == ACCELEROMETER_1g5) {
	   	ACCELEROMETER_CONTROL &= ~((1<<GS1)|(1<<GS2));//clear GS1 and GS2
		sensitivity = ACCELEROMETER_1g5_SENSITIVITY;
	    }
	else if (range == ACCELEROMETER_2g) {
		ACCELEROMETER_CONTROL &= ~(1<<GS2);//clear GS2
		ACCELEROMETER_CONTROL |= (1<<GS1);//set GS1
		sensitivity = ACCELEROMETER_2g_SENSITIVITY;
	    }
	else if (range == ACCELEROMETER_4g) {
		ACCELEROMETER_CONTROL &= ~(1<<GS1);//Clear GS1
		ACCELEROMETER_CONTROL |= (1<<GS2);//Set GS2
		sensitivity = ACCELEROMETER_4g_SENSITIVITY;
	    }
	else if (range == ACCELEROMETER_6g) {
	 	ACCELEROMETER_CONTROL |= ((1<<GS1)|(1<<GS2));//Set GS1 & GS2
		sensitivity = ACCELEROMETER_6g_SENSITIVITY;
	    }
}

void enableAccelerometer(unsigned char sleep)
{
 	 if(sleep == OFF){	  
	 	ACCELEROMETER_CONTROL &= ~(1<<SLEEP); // Disable Accelerometer
	    }
	 else {
	  	ACCELEROMETER_CONTROL |= (1<<SLEEP); // Enable Accelerometer
	    }
}


int readAccelerometer(unsigned char axis)
{
 	int value = 0;
	
 	if(axis == X_AXIS)  {
		value = Read_ADC(0x01);// ADC1
		}
	else if(axis == Y_AXIS) {
	    value = Read_ADC(0x06);  //  ADC6
	    }
	else if(axis == Z_AXIS) {
	    value = Read_ADC(0x07); //  ADC7
		
	    }

	return value;
}

